@@ -16,16 +16,21 @@ def index(request):
     )
 
 
+last_id = 'None'
+
+
 def build(request):
-    last_id = request.session.get('last_bakery_task_id', None)
-    if last_id:
+    """
+    from django.core.cache import caches
+    if 'last_id' in caches:
         task = app.AsyncResult(last_id)
         if task.ready():
             task = bakery_build.delay()
-            request.session['last_bakery_task_id'] = task.id
+            caches['last_id'] = task.id
             return HttpResponse("Build is running !")
         return HttpResponse("Build is already running !")
     else:
         task = bakery_build.delay()
-        request.session['last_bakery_task_id'] = task.id
-        return HttpResponse("Build is running !")
+        caches['last_id'] = task.id
+    """
+    return HttpResponse("Build is running !")
