@@ -1,6 +1,9 @@
 from django.template import (Library, Node)
 import json
+import logging
 
+
+logger = logging.getLogger('minify_schema')
 register = Library()
 
 
@@ -14,6 +17,9 @@ class MinifySchema(Node):
         try:
             return json.dumps(json.loads(ld))
         except Exception:
+            logger.error(str(ld))
+            import pdb
+            pdb.set_trace()
             return ''
 
 
